# Plotify
Make beautiful plots, fast.

Plotify is in active development. It is an intuitive wrapper around Matplotlib, Moviepy, and others that allows to easily create plots and animations.

Checkout the scripts in `tests` and the results in `outputs`.

Python 3.3+.
